@@ -67,6 +67,7 @@ class GitHub(object):
         self,
         auth=None,
         project='broad-bitsdb-firestore',
+        app_project=None,
         bitsdb_project='broad-bitsdb-prod',
     ):
         """Return a Firestore instance."""
@@ -75,6 +76,7 @@ class GitHub(object):
             auth,
             self,
             project=project,
+            app_project=app_project,
             bitsdb_project=bitsdb_project,
         )
 
