@@ -31,7 +31,7 @@ class Update(object):
     def _get_firestore_github_users(self):
         """Return a dict of cached GitHub users from Firestore."""
         github_users = {}
-        firestore = self.github.firestore()
+        firestore = self.github.firestore(app_project='broad-github-app')
         for doc in firestore.app.collection('github_users').stream():
             github_id = doc.id
             github_users[github_id] = doc.to_dict()
@@ -350,14 +350,14 @@ class Update(object):
         print('Found {} People in BITSdb.'.format(len(self.people)))
 
         # firestore - get team syncs
-        firestore = self.github.firestore()
+        firestore = self.github.firestore(app_project='broad-github-app')
         team_syncs = firestore.get_team_syncs_dict()
         print('Found {} GitHub Team Syncs in BITSdb.'.format(len(team_syncs)))
 
         for slug in sorted(team_syncs):
             s = team_syncs[slug]
-            team_id = s['github_team']
-            email = s['google_group']
+            team_id = s['team_id']
+            email = s['group_email']
             self.update_team(slug, team_id, email)
 
         if self.verbose:
